@@ -5,6 +5,9 @@ import requests
 
 
 class OisManager:
+    """
+    Handles the tois, kois and epic ois for the different missions. Updates them from the proper web services.
+    """
     TOIS_CSV_URL = 'https://exofop.ipac.caltech.edu/tess/download_toi.php?sort=toi&output=csv'
     CTOIS_CSV_URL = 'https://exofop.ipac.caltech.edu/tess/download_ctoi.php?sort=ctoi&output=csv'
     KOIS_LIST_URL = 'https://exofop.ipac.caltech.edu/kepler/targets.php?sort=num-pc&page1=1&ipp1=100000&koi1=&koi2='
@@ -20,8 +23,9 @@ class OisManager:
     KIC_STAR_CSV = 'kic_star.csv'
     ois = None
 
-    def __init__(self):
-        home = str(Path.home()) + "/.sherlockpipe/"
+    def __init__(self, cache_dir):
+        self.cache_dir = cache_dir
+        home = self.cache_dir + "/.sherlockpipe/"
         if not os.path.exists(home):
             os.mkdir(home)
         self.tois_csv = home + self.TOIS_CSV
@@ -31,6 +35,10 @@ class OisManager:
         self.kic_star_csv = home + self.KIC_STAR_CSV
 
     def load_ois(self):
+        """
+        Loads all the ois in an in-memory dataframe.
+        @return: the ois dataframe
+        """
         if not os.path.isfile(self.tois_csv) or not os.path.isfile(self.ctois_csv):
             print("TOIs files are not found. Downloading...")
             self.update_tic_csvs()
@@ -54,6 +62,10 @@ class OisManager:
         return ois
 
     def update_tic_csvs(self):
+        """
+        Reloads the TESS Objects of Interest.
+        @return: the OisManager class to be used as a fluent API.
+        """
         tic_csv = open(self.tois_csv, 'wb')
         request = requests.get(self.TOIS_CSV_URL)
         tic_csv.write(request.content)
@@ -81,6 +93,10 @@ class OisManager:
         return self
 
     def update_kic_csvs(self):
+        """
+        Reloads the Kepler Objects of Interest.
+        @return: the OisManager class to be used as a fluent API.
+        """
         koi_csv = open(self.kois_csv, 'wb')
         request = requests.get(self.KOI_CSV_URL)
         koi_csv.write(request.content)
@@ -122,6 +138,10 @@ class OisManager:
         return self
 
     def update_epic_csvs(self):
+        """
+        Reloads the K2 Objects of Interest.
+        @return: the OisManager class to be used as a fluent API.
+        """
         epic_csv = open(self.epic_csv, 'wb')
         request = requests.get(self.EPIC_CSV_URL)
         epic_csv.write(request.content)
@@ -129,19 +149,22 @@ class OisManager:
         epic_data = pd.read_csv(self.epic_csv)
         epic_data['pl_trandep'] = epic_data['pl_trandep'].astype(float) * 1000000
         epic_data['pl_tranmid'] = epic_data['pl_tranmid'].astype(float) - epic_data['pl_trandur'].astype(float) / 2
-        epic_data['ra_str'] = epic_data['ra_str'].astype(str).replace("h", ":").replace("m", ":").replace("s", "")
-        epic_data['dec_str'] = epic_data['dec_str'].astype(str).replace("d", ":").replace("m", ":").replace("s", "")
-        epic_data = epic_data.rename(columns={'epic_candname': 'OI', 'epic_name': 'Object Id',
-                                            'k2c_disp': 'Disposition', 'pl_trandur': 'Duration (hours)',
+        epic_data['ra'] = epic_data['ra'].astype(str).replace("h", ":").replace("m", ":").replace("s", "")
+        epic_data['dec'] = epic_data['dec'].astype(str).replace("d", ":").replace("m", ":").replace("s", "")
+        epic_data[epic_data['disposition'] == "CANDIDATE"]['disposition'] = "PC"
+        epic_data[epic_data['disposition'] == "CONFIRMED"]['disposition'] = "CP"
+        epic_data[epic_data['disposition'] == "FALSE POSITIVE"]['disposition'] = "FP"
+        epic_data = epic_data.rename(columns={'pl_name': 'OI', 'epic_hosname': 'Object Id',
+                                            'disposition': 'Disposition', 'pl_trandur': 'Duration (hours)',
                                             'pl_orbper': 'Period (days)',
                                             'pl_tranmid': 'Epoch (BJD)',
                                             'pl_trandep': 'Depth (ppm)',
                                             'pl_eqt': 'Planet Equil Temp (K)',
-                                            'ra_str': 'RA', 'dec_str': 'Dec',
+                                            'ra': 'RA', 'dec': 'Dec',
                                             'st_logg': 'Stellar log(g) (cm/s^2)',
                                             'st_teff': 'Stellar Eff Temp (K)',
                                             'pl_rade': 'Planet Radius (R_Earth)',
-                                            'st_dist': 'Stellar Distance (pc)',
-                                            'st_metfe': 'Stellar Metallicity'})
+                                            'sy_dist': 'Stellar Distance (pc)',
+                                            'st_metratio': 'Stellar Metallicity'})
         epic_data.to_csv(self.epic_csv, index=False)
         return self
